==> cantor-17.12.3.tar.xz: cantor-17.12.3/src/backends/julia/juliahighlighter.h <==
/*
 *    This program is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU General Public License
 *    as published by the Free Software Foundation; either version 2
 *    of the License, or (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *    Boston, MA  02110-1301, USA.
 *
 *    ---
 *    Copyright (C) 2016 Ivan Lakhtanov <ivan.lakhtanov@gmail.com>
 */
#pragma once

#include "defaulthighlighter.h"

/**
 * Implementation of JuliaHighlighter
 *
 * Takes into account loaded symbols from scope and predefined keywords.
 * There is no common regexps that bound to fail with such syntax-overloaded
 * languages as Julia
 */
class JuliaHighlighter: public Cantor::DefaultHighlighter
{
    Q_OBJECT

public:
    /**
     * Constructs JuliaHighlighter
     *
     * @param parent QObject parent
     */
    JuliaHighlighter(QObject *parent);
    virtual ~JuliaHighlighter() {}

public Q_SLOTS:
    /**
     * Call this to update highlighter to the current state of keywords storage
     */
    void updateHighlight();

protected:
    /**
     * @see Cantor::DefaultHighlighter::highlightBlock
     */
    virtual void highlightBlock(const QString &text) override;

    /**
     * @see Cantor::DefaultHighlighter::nonSeparatingCharacters
     */
    virtual QString nonSeparatingCharacters() const override;
};

==> cantor_18.12.0.orig.tar.xz: cantor-18.12.0/src/backends/julia/juliahighlighter.h <==
/*
 *    This program is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU General Public License
 *    as published by the Free Software Foundation; either version 2
 *    of the License, or (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *    Boston, MA  02110-1301, USA.
 *
 *    ---
 *    Copyright (C) 2016 Ivan Lakhtanov <ivan.lakhtanov@gmail.com>
 */
#pragma once

#include "defaulthighlighter.h"

/**
 * Implementation of JuliaHighlighter
 *
 * Takes into account loaded symbols from scope and predefined keywords.
 * There is no common regexps that bound to fail with such syntax-overloaded
 * languages as Julia
 */
class JuliaHighlighter: public Cantor::DefaultHighlighter
{
    Q_OBJECT

public:
    /**
     * Constructs JuliaHighlighter
     *
     * @param parent QObject parent
     */
    explicit JuliaHighlighter(QObject *parent);
    ~JuliaHighlighter() override = default;

public Q_SLOTS:
    /**
     * Call this to update highlighter to the current state of keywords storage
     */
    void updateHighlight();

protected:
    /**
     * @see Cantor::DefaultHighlighter::highlightBlock
     */
    void highlightBlock(const QString &text) override;

    /**
     * @see Cantor::DefaultHighlighter::nonSeparatingCharacters
     */
    QString nonSeparatingCharacters() const override;
};
